/**
 * <copyright>
 *
 * Copyright (c) 2006 IBM Corporation and others.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors: 
 *   IBM - Initial API and implementation
 *
 * </copyright>
 *
 * $Id$
 */
package org.eclipse.jet.internal;


/**
 * Utility class for Java related code generation.
 */
public class JavaUtil
{

  /**
   * 
   */
  private JavaUtil()
  {
    super();
  }

  public static String escapeJavaString(char[] text)
  {
    StringBuffer buffer = new StringBuffer(text.length);
    JavaUtil.escapeJavaString(text, buffer);
    return buffer.toString();
  }

  /**
   * @param originalText
   * @param escapedText
   */
  public static void escapeJavaString(char[] originalText, StringBuffer escapedText)
  {
    for (int i = 0; i < originalText.length; i++)
    {
      switch (originalText[i])
      {
        case '\b':
          escapedText.append("\\b"); //$NON-NLS-1$
          break;
        case '\f':
          escapedText.append("\\f"); //$NON-NLS-1$
          break;
        case '\t':
          escapedText.append("\\t"); //$NON-NLS-1$
          break;
        case '\r':
          escapedText.append("\\r"); //$NON-NLS-1$
          break;
        case '\n':
          escapedText.append("\\n"); //$NON-NLS-1$
          break;
        case '"':
          escapedText.append("\\\""); //$NON-NLS-1$
          break;
        case '\\':
          escapedText.append("\\\\"); //$NON-NLS-1$
          break;
        default:
          escapedText.append(originalText[i]);
      }
    }
  }

  /**
   * Return a Java string, including initial and final double quotes, and inserting
   * any required Java escape sequences.
   * @param text the text to quote
   * @return the quoted Java string
   */
  public static String asJavaQuotedString(char[] text)
  {
    StringBuffer encoded = new StringBuffer(text.length + 2);
    encoded.append('"');
  
    escapeJavaString(text, encoded);
  
    encoded.append('"');
    return encoded.toString();
  }

}
