/**
 * <copyright>
 *
 * Copyright (c) 2006 IBM Corporation and others.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors: 
 *   IBM - Initial API and implementation
 *
 * </copyright>
 *
 * $Id$
 */
package org.eclipse.jet.internal.compiler;


import java.text.MessageFormat;

import org.eclipse.jet.compiler.Problem;
import org.eclipse.jet.internal.l10n.JET2Messages;
import org.eclipse.jet.internal.parser.JETMark;
import org.eclipse.jet.internal.parser.JETParseEventListener2;
import org.eclipse.jet.internal.parser.JETReader;
import org.eclipse.jet.internal.parser.ParseProblemSeverity;


/**
 * Utility class to aid in handling file errors
 */
public class CompilerErrorUtil
{

  /**
   * 
   */
  private CompilerErrorUtil()
  {
  }

  /**
   * Record a parse error for a JET element whose close sequence is missing.
   * @param listener the JETParseEventLister2
   * @param expectedCloseSequence the expected close sequence
   * @param elementStart the JETMark for the start of the element
   * @param reader the current JETReader
   */
  public static void recordUnterminatedElement(
    JETParseEventListener2 listener,
    String expectedCloseSequence,
    JETMark elementStart,
    JETReader reader)
  {
    // FIXME: Note that we use XPath_Expected (text: Expected: {0}) because the message "jet.error.unterminated"
    // in the codegen plug-in is incorrect.
    listener.recordProblem(
      ParseProblemSeverity.ERROR,
      Problem.UnterminatedXMLTag,
      JET2Messages.XPath_Expected,
      new Object []{ expectedCloseSequence },
      elementStart.getCursor(),
      reader.mark().getCursor(),
      elementStart.getLine(),
      elementStart.getCol());

  }
  
  /**
   * Return the formatted error message for an unterminated string.
   * @param openSequence
   * @param expectedCloseSequence
   * @param reader
   * @return
   */
  public static String getUnterminatedMessage(String openSequence, String expectedCloseSequence, JETReader reader) {
    // This method encapsulates the retrieval of the 'unterminated' error message. Because this message is part
    // of EMF Codegen, and it is incorect (it incorrectly uses the first argument twice), we centralize
    // access to it, and implement the 'fix' once.
    // This is the 'unfixed' code:
//    final String msg = CodeGenPlugin.getPlugin().getString(
//      "jet.error.unterminated", //$NON-NLS-1$
//      new Object []{ openSequence, reader.mark().toString() });

    // FIXME: Note that we use XPath_Expected (text: Expected: {0}) because the message "jet.error.unterminated"
    // in the codegen plug-in is incorrect.
    return MessageFormat.format(JET2Messages.XPath_Expected, new Object[] {expectedCloseSequence});
  }
}
