/**
 * <copyright>
 *
 * Copyright (c) 2005 IBM Corporation and others.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors: 
 *   IBM - Initial API and implementation
 *
 * </copyright>
 *
 * $Id$
 */

package org.eclipse.jet.internal.compiler;


import java.util.Collections;
import java.util.HashMap;
import java.util.Map;

import org.eclipse.core.resources.IProject;
import org.eclipse.jet.compiler.IJETCompilerState;


/**
 * Manager compiler state stored in the workspace meta data.
 * @deprecated Don't think we need this
 */
public class CompilerStateManager
{

  private final Map projectCache = Collections.synchronizedMap(new HashMap());

  /**
   * 
   */
  public CompilerStateManager()
  {
    super();
  }

  /**
   * Return the cached compiler state for the identified project.
   * Create a compiler state if it does not exist.
   * @param project
   * @return the compiler state
   */
  public IJETCompilerState getCompilerState(IProject project)
  {
    IJETCompilerState compilerState = (IJETCompilerState)projectCache.get(project.getName());

    if (compilerState == null)
    {
      compilerState = new JETCompilerState();
      projectCache.put(project.getName(), compilerState);
    }

    return compilerState;
  }

  /**
   * Associate the compiler state with a JET2 project.
   * @param project an Eclipse workspace project (containing a JET2 builder).
   * @param compilerState the compiler state.
   */
  public void setCompilerState(IProject project, IJETCompilerState compilerState)
  {
    projectCache.put(project.getName(), compilerState);
  }

}
