/**
 * <copyright>
 *
 * Copyright (c) 2005 IBM Corporation and others.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors: 
 *   IBM - Initial API and implementation
 *
 * </copyright>
 *
 * $Id$
 */

package org.eclipse.jet.internal.compiler;


import org.eclipse.jet.compiler.Comment;
import org.eclipse.jet.compiler.DefaultJET2ASTVisitor;
import org.eclipse.jet.compiler.JET2ASTElement;
import org.eclipse.jet.compiler.JET2ASTVisitor;
import org.eclipse.jet.compiler.JET2Declaration;
import org.eclipse.jet.compiler.JET2Directive;
import org.eclipse.jet.compiler.JET2Expression;
import org.eclipse.jet.compiler.JET2Scriptlet;
import org.eclipse.jet.compiler.TextElement;
import org.eclipse.jet.compiler.XMLBodyElement;
import org.eclipse.jet.compiler.XMLBodyElementEnd;
import org.eclipse.jet.compiler.XMLEmptyElement;
import org.eclipse.jet.internal.parser.LineInfo;


/**
 * A JET AST Visitor that strips whitespace and new-lines
 * 
 */
public class TextTrimmingVisitor extends DefaultJET2ASTVisitor implements JET2ASTVisitor
{
  /**
   * 
   */
  public TextTrimmingVisitor()
  {
    super();
  }

  private void checkAndStrip(JET2ASTElement element)
  {
    if(element.removeLineWhenOtherwiseEmpty())
    {
      JET2ASTElement prev = element.getPrevElement();
      JET2ASTElement next = element.getNextElement();
      if(endsWithEmtpyLine(prev) && startsWithEmptyLine(next))
      {
        trimLastLine(prev);
        trimFirstLine(next);
      }
    }
  }

  private void trimLastLine(JET2ASTElement element)
  {
    if(element instanceof TextElement)
    {
      TextElement text = (TextElement)element;
      text.setTrimLastLine(true);
    }
  }

  private void trimFirstLine(JET2ASTElement element)
  {
    if(element instanceof TextElement)
    {
      TextElement text = (TextElement)element;
      text.setTrimFirstLine(true);
    }
  }

  private boolean startsWithEmptyLine(JET2ASTElement element)
  {
    if(element instanceof TextElement)
    {
      TextElement text = (TextElement)element;
      final LineInfo[] lines = text.getLines();
      if(lines.length > 0 && lines[0].hasDelimiter())
      {
        LineInfo line = lines[0];
        if(new String(text.getRawText(), line.getStart(), line.getEnd() - line.getStart()).trim().length() == 0)
        {
          // first line is all whitespace
          return true;
        }
      }
    }
    else if(element == null)
    {
      return true;
    }
    return false;
  }

  private boolean endsWithEmtpyLine(JET2ASTElement element)
  {
    if(element instanceof TextElement)
    {
      TextElement text = (TextElement)element;
      final LineInfo[] lines = text.getLines();
      if(lines.length > 0)
      {
        LineInfo line = lines[lines.length - 1];
        if(line.hasDelimiter()) {
          // last line has a delimiter => this element start on col # 1
          return true;
        }
        else if( lines.length > 1 && new String(text.getRawText(), line.getStart(), line.getEnd() - line.getStart()).trim().length() == 0)
        {
          // last line is all whitespace
          return true;
        }
      }
      else
      {
        return false;
      }
    }
    else if(element == null)
    {
      return true;
    }
    return false;
  }

  public void visit(JET2Declaration declaration)
  {
    checkAndStrip(declaration);
  }

  public void visit(JET2Directive directive)
  {
    checkAndStrip(directive);
  }

  public void visit(JET2Expression expression)
  {
    checkAndStrip(expression);
  }

  public void visit(JET2Scriptlet scriptlet)
  {
    checkAndStrip(scriptlet);
  }

  public void visit(XMLEmptyElement xmlEmptyElement)
  {
    checkAndStrip(xmlEmptyElement);
  }

  public void visit(XMLBodyElement xmlBodyElement)
  {
    checkAndStrip(xmlBodyElement);
  }

  public void visit(XMLBodyElementEnd xmlBodyElementEnd)
  {
    checkAndStrip(xmlBodyElementEnd);
  }

  public void visit(Comment comment)
  {
    checkAndStrip(comment);
  }
}
