package org.eclipse.jet.internal.compiler.templates;

import java.util.HashMap;
import java.util.Map;

import org.eclipse.jet.JET2TemplateLoader;
import org.eclipse.jet.JET2TemplateLoaderExtension;
import org.eclipse.jet.JET2Template;

public class CodeGenTemplateLoader implements JET2TemplateLoader, JET2TemplateLoaderExtension {

	private static final class TemplateFactoryMethod {

		private final String templatePath;
		private final String templateClass;

		public TemplateFactoryMethod(String templatePath, String templateClass) {
			this.templatePath = templatePath;
			this.templateClass = templateClass;
			
		}
		
		public String getTemplateClass() {
			return templateClass;
		}

		public String getTemplatePath() {
			return templatePath;
		}

		public JET2Template newTemplate() {
			JET2Template template = null;
			try {
				template = (JET2Template) Class.forName(templateClass).newInstance();
			} catch (InstantiationException e) {
			} catch (IllegalAccessException e) {
			} catch (ClassNotFoundException e) {
			}
			return template;
		}
		
		
	}

	private Map pathToFactoryMap = null;
	
	private JET2TemplateLoader delegate = null;

	public CodeGenTemplateLoader() {
		super();
	}

	public JET2Template getTemplate(String templatePath) {
	    if(pathToFactoryMap == null) {
   	        initPathToFactoryMap();
        }
        TemplateFactoryMethod factory = (TemplateFactoryMethod)pathToFactoryMap.get(templatePath);
		return factory == null ? delegate == null ? null : delegate.getTemplate(templatePath) : factory.newTemplate();
	}

	private void addTemplate(String templatePath, String templateClass) {
		pathToFactoryMap.put(templatePath, //$NON-NLS-1$
		    new TemplateFactoryMethod(templatePath, templateClass));
	}
	
    private void initPathToFactoryMap() {
	        pathToFactoryMap = new HashMap(8);
		    addTemplate("templates/writeJavaExpression.jet", "org.eclipse.jet.internal.compiler.templates.WriteJavaExpressionTemplate" ); //$NON-NLS-1$  //$NON-NLS-2$
		    addTemplate("templates/jet2java.jet", "org.eclipse.jet.internal.compiler.templates.JET2JavaGenerator" ); //$NON-NLS-1$  //$NON-NLS-2$
		    addTemplate("templates/xmlStart.jet", "org.eclipse.jet.internal.compiler.templates.XMLStartGenerator" ); //$NON-NLS-1$  //$NON-NLS-2$
		    addTemplate("templates/main.jet", "org.eclipse.jet.internal.compiler.templates.DummyMain" ); //$NON-NLS-1$  //$NON-NLS-2$
		    addTemplate("templates/jet2transform.jet", "org.eclipse.jet.internal.compiler.templates.JET2TransformGenerator" ); //$NON-NLS-1$  //$NON-NLS-2$
		    addTemplate("templates/xmlEnd.jet", "org.eclipse.jet.internal.compiler.templates.XMLEndGenerator" ); //$NON-NLS-1$  //$NON-NLS-2$
		    addTemplate("templates/tagDataDeclarations.jet", "org.eclipse.jet.internal.compiler.templates.TagDataDeclGenerator" ); //$NON-NLS-1$  //$NON-NLS-2$
		    addTemplate("templates/writeTextElement.jet", "org.eclipse.jet.internal.compiler.templates.WriteTextElementTemplate" ); //$NON-NLS-1$  //$NON-NLS-2$
	}

    public void setDelegateLoader(JET2TemplateLoader loader) {
        this.delegate = loader;
    }
    
    public JET2TemplateLoader getDelegateLoader() {
        return delegate;
    }
}

